@@ -1,11 +1,10 @@
+#include <cpp11.hpp>
 #include "pch.h"
 #include "DbColumnStorage.h"
 #include "DbColumnDataSource.h"
 #include "integer64.h"
 
 
-using namespace Rcpp;
-
 DbColumnStorage::DbColumnStorage(DATA_TYPE dt_, const R_xlen_t capacity_, const int n_max_,
                                  const DbColumnDataSource& source_)
   :
@@ -36,7 +35,7 @@ DATA_TYPE DbColumnStorage::get_data_type() const {
 
 SEXP DbColumnStorage::allocate(const R_xlen_t length, DATA_TYPE dt) {
   SEXPTYPE type = sexptype_from_datatype(dt);
-  RObject class_ = class_from_datatype(dt);
+  cpp11::sexp class_ = class_from_datatype(dt);
 
   SEXP ret = PROTECT(Rf_allocVector(type, length));
   if (!Rf_isNull(class_)) Rf_setAttrib(ret, R_ClassSymbol, class_);
@@ -148,7 +147,7 @@ void DbColumnStorage::fetch_value() {
     break;
 
   default:
-    stop("NYI");
+    cpp11::stop("NYI");
   }
 }
 
@@ -180,21 +179,21 @@ SEXPTYPE DbColumnStorage::sexptype_from_datatype(DATA_TYPE dt) {
     return VECSXP;
 
   default:
-    stop("Unknown type %d", dt);
+    cpp11::stop("Unknown type %d", dt);
   }
 }
 
-Rcpp::RObject DbColumnStorage::class_from_datatype(DATA_TYPE dt) {
+cpp11::sexp DbColumnStorage::class_from_datatype(DATA_TYPE dt) {
   switch (dt) {
   case DT_INT64:
-    return CharacterVector::create("integer64");
+    return cpp11::writable::strings({"integer64"});
 
   case DT_DATE:
-    return CharacterVector::create("Date");
+    return cpp11::strings(cpp11::as_sexp(cpp11::r_string("Date")));
 
   case DT_DATETIME:
   case DT_DATETIMETZ:
-    return CharacterVector::create("POSIXct", "POSIXt");
+    return cpp11::strings({"POSIXct", "POSIXt"});
 
   default:
     return R_NilValue;
@@ -210,7 +209,7 @@ SEXP DbColumnStorage::set_attribs_from_datatype(SEXP x, DATA_TYPE dt) {
     return new_hms(x);
 
   case DT_DATETIME: {
-      Rcpp::RObject ro = Rcpp::RObject(x);
+      cpp11::sexp ro = x;
       ro.attr("tzone") = "UTC";
       return ro;
     }
@@ -220,12 +219,12 @@ SEXP DbColumnStorage::set_attribs_from_datatype(SEXP x, DATA_TYPE dt) {
 }
 
 SEXP DbColumnStorage::new_blob(SEXP x) {
-  static Function new_blob = Function("new_blob", Rcpp::Environment::namespace_env("blob"));
+  static cpp11::function new_blob = cpp11::package("blob")["new_blob"];
   return new_blob(x);
 }
 
 SEXP DbColumnStorage::new_hms(SEXP x) {
-  static Function new_hms = Function("new_hms", Rcpp::Environment::namespace_env("hms"));
+  static cpp11::function new_hms = cpp11::package("hms")["new_hms"];
   return new_hms(x);
 }
 
@@ -260,7 +259,7 @@ void DbColumnStorage::fill_default_value(SEXP data, DATA_TYPE dt, R_xlen_t i) {
     break;
 
   case DT_UNKNOWN:
-    stop("Not setting value for unknown data type");
+    cpp11::stop("Not setting value for unknown data type");
   }
 }
 
@@ -333,7 +332,7 @@ void DbColumnStorage::copy_value(SEXP x, DATA_TYPE dt, const int tgt, const int
       break;
 
     default:
-      stop("NYI: default");
+      cpp11::stop("NYI: default");
     }
   }
 }
