@@ -1,6 +1,7 @@
 #ifndef __RSQLITE_SQLITE_RESULT__
 #define __RSQLITE_SQLITE_RESULT__
 
+#include <cpp11.hpp>
 #include "DbResult.h"
 
 // DbResult --------------------------------------------------------------------
@@ -13,7 +14,7 @@ public:
   static DbResult* create_and_send_query(const DbConnectionPtr& con, const std::string& sql);
 
 public:
-  CharacterVector get_placeholder_names() const;
+  cpp11::strings get_placeholder_names() const;
 };
 
 #endif
